==> keyclic_sdk_api-1.39.1.tar.gz: lib/model/log_entry_pagination.dart <==
part of keyclic_sdk_api.api;

class LogEntryPagination {
  int limit = null;

  int page = null;

  int pages = null;

  int total = null;

  LogEntryCollection embedded = null;

  PaginationLinks links = null;

  LogEntryPagination({
    this.limit,
    this.page,
    this.pages,
    this.total,
    this.embedded,
    this.links,
  });

  @override
  String toString() {
    return 'LogEntryPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  LogEntryPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = new LogEntryCollection.fromJson(json['_embedded']);
    links = new PaginationLinks.fromJson(json['_links']);
  }

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      '_embedded': embedded,
      '_links': links,
    };
  }

  static List<LogEntryPagination> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<LogEntryPagination>()
        : json.map((value) => new LogEntryPagination.fromJson(value)).toList();
  }

  static Map<String, LogEntryPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, LogEntryPagination>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new LogEntryPagination.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.39.4.tar.gz: lib/model/log_entry_pagination.dart <==
part of keyclic_sdk_api.api;

class LogEntryPagination {
  LogEntryPagination({
    this.limit,
    this.page,
    this.pages,
    this.total,
    this.embedded,
    this.links,
  });

  LogEntryPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = LogEntryCollection.fromJson(json['_embedded']);
    links = PaginationLinks.fromJson(json['_links']);
  }

  int limit;

  int page;

  int pages;

  int total;

  LogEntryCollection embedded;

  PaginationLinks links;

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      '_embedded': embedded,
      '_links': links,
    };
  }

  @override
  String toString() {
    return 'LogEntryPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  static List<LogEntryPagination> listFromJson(List<dynamic> json) {
    return json == null
        ? List<LogEntryPagination>()
        : json.map((value) => LogEntryPagination.fromJson(value)).toList();
  }

  static Map<String, LogEntryPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, LogEntryPagination>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = LogEntryPagination.fromJson(value));
    }
    return map;
  }
}
